==Simple Agents==

This is a legacy package, left for backward compatibility.
Here you see initial implementation of agents, which are now deprecated.
These implementations are simplier than the current ones but with less features.
